@@ -1,10 +1,10 @@
 import keras
 from tensorflow.keras.callbacks import LambdaCallback
-import .eval_measure
-from .corpus import DocData,DocDatalstm
-import ldann
-from ldann import Doc2Topic,Logger,data_feeder,Doc2Topiclstm
-from .eval_measure import custom_evaluator
+import topicmodels.eval_measure
+from topicmodels.corpus import DocData,DocDatalstm
+import topicmodels.ldann
+from topicmodels.ldann import Doc2Topic,Logger,data_feeder,Doc2Topiclstm
+from topicmodels.eval_measure import custom_evaluator
 import os
 import collections
 import numpy as np
